# Satcat SDK

Official client for accessing and integrating Satcat platform data services, including conjunction assessment, catalog screening, ephemeris management, and operator coordination. Designed for expert use in SSA and mission operations environments.

More information:

- [Satcat SDK Docs](https://kayhan-oss.gitlab.io/satcat-sdk/latest/index.html)
- [Satcat Docs](https://docs.satcat.com/)
- [satcat.com](https://www.satcat.com/)